package issue;

import java.io.Serializable;
import java.util.Objects;

public class Issue implements Serializable {

    private static final long serialVersionUID = 1L;
    private String title;
    private String description;
    private String originalHash;
    private long creationTime;
    private long edited;


    public Issue(String title, String description) {
        this.title = title;
        this.description = description;
        long time = System.currentTimeMillis();
        this.creationTime = time + 1;
        this.edited = time + 1;
        this.originalHash = String.valueOf(hashCode());
    }

    public void setTitle(String title) {
        this.title = title;
        edited();
    }

    public void setDescription(String description) {
        this.description = description;
        edited();
    }

    private void edited(){
        edited = System.currentTimeMillis();
    }

    public String getTitle(){
        return this.title;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        Issue issue = (Issue) o;
        return creationTime == issue.creationTime &&
                Objects.equals(title, issue.title) &&
                Objects.equals(description, issue.description);
    }

    @Override
    public int hashCode() {
        return Objects.hash(title, description, creationTime);
    }

    @Override
    public String toString() {
        return "Title: " + title + " Description: " + description;
    }

    public String getOriginalHash() {
        return originalHash;
    }
}
